#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-extra
version:              0.4.2.1
visibility:           public
id:                   optics-extra-0.4.2.1-2a3320nCkFI1yBU3uKei9a
key:                  optics-extra-0.4.2.1-2a3320nCkFI1yBU3uKei9a
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Extra utilities and instances for optics-core
description:
    This package provides extra definitions and instances that extend the
    @<https://hackage.haskell.org/package/optics-core optics-core>@ package,
    without incurring too many dependencies.  See the
    @<https://hackage.haskell.org/package/optics optics>@ package for more
    documentation.

category:             Data, Optics, Lenses
abi:                  6554b4ec46a851b28437e7204e922e56
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Optics Data.ByteString.Optics
    Data.ByteString.Strict.Optics Data.HashMap.Optics
    Data.HashSet.Optics Data.Text.Lazy.Optics Data.Text.Optics
    Data.Text.Strict.Optics Data.Vector.Generic.Optics
    Data.Vector.Optics Optics.At Optics.Cons Optics.Each Optics.Empty
    Optics.Extra Optics.Extra.Internal.ByteString
    Optics.Extra.Internal.Vector Optics.Extra.Internal.Zoom
    Optics.Indexed Optics.Passthrough Optics.State
    Optics.State.Operators Optics.View Optics.Zoom

import-dirs:          /usr/lib/ghc-9.6.6/site-local/optics-extra-0.4.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/optics-extra-0.4.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/optics-extra-0.4.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-extra
hs-libraries:         HSoptics-extra-0.4.2.1-2a3320nCkFI1yBU3uKei9a
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    indexed-profunctors-0.1.1.1-L2HakkjbDHqHKFSw687hVU
    indexed-traversable-instances-0.1.2.1-KlOfhzX4GI0KhVQgaPdVcz
    mtl-2.3.1 optics-core-0.4.2-Aksz8PRnmoL4plTZQxkU8c text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU

haddock-interfaces:
    /usr/share/doc/haskell-optics-extra/html/optics-extra.haddock

haddock-html:         /usr/share/doc/haskell-optics-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

